API Reference
=============

.. autofunction:: crochet.setup()
.. autofunction:: crochet.no_setup()
.. autofunction:: crochet.run_in_reactor(function)
.. autofunction:: crochet.wait_for(timeout)
.. autoclass:: crochet.EventualResult
   :members:
.. autofunction:: crochet.retrieve_result(result_id)
.. autoexception:: crochet.TimeoutError
.. autoexception:: crochet.ReactorStopped
